/*
jGuard is a security framework based on top of jaas (java authentication and authorization security).
it is written for web applications, to resolve simply, access control problems.
version $Name$
http://sourceforge.net/projects/jguard/

Copyright (C) 2004  Charles GAY

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


jGuard project home page:
http://sourceforge.net/projects/jguard/

*/
package net.sf.jguard.jsf.authentication;

import java.security.Principal;

import javax.portlet.PortletRequest;
import javax.portlet.PortletSession;

import net.sf.jguard.core.CoreConstants;
import net.sf.jguard.core.authentication.AuthenticationUtils;
import net.sf.jguard.core.authentication.manager.AuthenticationManager;
import net.sf.jguard.ext.SecurityConstants;
import net.sf.jguard.jee.authentication.http.JEERequestWrapperUtil;

public class JGuardPortletRequestWrapper extends PortletRequestWrapper {

	public JGuardPortletRequestWrapper(PortletRequest request) {
		super(request);
	}

	/**
	 * wrap the isUserInRole method to check against
	 * all the {@link RolePrincipal}'s set of the Subject object.
	 * @param role : name of the principal(role) we are looking for
	 * @return boolean :return 'true' if one of the principal the Subject
	 * owns has got the same name.return 'false' otherwise.
	 */
    public boolean isUserInRole(String role){
    	PortletSession session = request.getPortletSession(true);
    	AuthenticationUtils authUtils = ((AuthenticationUtils)session.getAttribute(CoreConstants.AUTHN_UTILS,PortletSession.APPLICATION_SCOPE));
    	String applicationName = (String)session.getPortletContext().getAttribute(CoreConstants.APPLICATION_NAME);
    	return JEERequestWrapperUtil.isUserInRole(applicationName,role, authUtils);
    }

	

    /**
     * return a SubjectAsPrincipal object which wrap the Subject
     * in a Principal.
     * @return principal
     */
    public Principal getUserPrincipal(){
    	AuthenticationUtils authUtils = ((AuthenticationUtils)request.getPortletSession(true).getAttribute(CoreConstants.AUTHN_UTILS,PortletSession.APPLICATION_SCOPE));
    	return JEERequestWrapperUtil.getUserPrincipal(authUtils);
    }

	

    /**
     *
     * @return remote user login credential String value
     */
    public String getRemoteUser(){
    	AuthenticationUtils authUtils = ((AuthenticationUtils)request.getPortletSession(true).getAttribute(CoreConstants.AUTHN_UTILS,PortletSession.APPLICATION_SCOPE));
        AuthenticationManager authnManager = (AuthenticationManager)request.getPortletSession(true).getAttribute(SecurityConstants.AUTHENTICATION_MANAGER,PortletSession.APPLICATION_SCOPE);
        
    	return JEERequestWrapperUtil.getRemoteUser(authUtils,authnManager);
    }

}
